CropRegion class
A named rectangular region to extract from a screenshot, in logical pixels.
Constructors
- CropRegion({required String name, required Rect rect})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Name used to derive the crop filename (e.g. 'header' → 'header.png').
final
- rect → Rect
-
Region to extract, in logical pixels relative to the full screenshot.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited